sl_create_engine function

  1. @Native<sl_engine_handle_t Function(Bool, Bool, Int32)>(ffi.Bool, ffi.Bool, ffi.Int32)>(assetId: _sweetlineAssetId)
sl_engine_handle_t sl_create_engine(
  1. bool show_index,
  2. bool inline_style,
  3. int tab_size
)

Create a SweetLine highlight engine @param show_index Whether the analysis result includes character index, if not only line and column are returned @param inline_style Whether the analysis result uses inline styles instead of only returning style IDs @param tab_size Tab width used for indent guide level calculation @return Highlight engine handle

Implementation

@ffi.Native<sl_engine_handle_t Function(ffi.Bool, ffi.Bool, ffi.Int32)>(
  assetId: _sweetlineAssetId,
)
external sl_engine_handle_t sl_create_engine(
  bool show_index,
  bool inline_style,
  int tab_size,
);