sl_document_analyze function
- @Native<Pointer<
Int32> Function(sl_analyzer_handle_t)>(sl_analyzer_handle_t)>(assetId: _sweetlineAssetId)
- sl_analyzer_handle_t analyzer_handle
Perform full highlight analysis on a managed document (typically called once after initial document load)
@param analyzer_handle Document highlight analyzer handle
@return Analysis result, tightly packed in byte order. Structure:
@code
Same format as sl_text_analyze:
flags, spanStride, lineCount, lineEntry...
@endcode
Note: the return value must be freed by calling sl_free_buffer after use
Implementation
@ffi.Native<ffi.Pointer<ffi.Int32> Function(sl_analyzer_handle_t)>(assetId: _sweetlineAssetId)
external ffi.Pointer<ffi.Int32> sl_document_analyze(
sl_analyzer_handle_t analyzer_handle,
);