sl_syntax_error class final

Syntax rule error information

Inheritance
Implemented types
Available extensions

Constructors

sl_syntax_error()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
err_code sl_error
no setter
err_codeAsInt int
Error code
getter/setter pair
err_msg Pointer<Char>
Error message
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited