sl_document_get_highlight_slice function
- sl_analyzer_handle_t analyzer_handle,
- Pointer<
Int32> visible_range
Get highlight slice from the current cached document highlight result
Requires prior call to sl_document_analyze or sl_document_analyze_incremental
@param analyzer_handle Document highlight analyzer handle
@param visible_range Visible line range, array structure: startLine,lineCount
@return Highlight slice for the specified line range, tightly packed in byte order. Structure:
@code
Same format as sl_document_analyze_incremental_in_line_range:
flags, spanStride, startLine, totalLineCount, lineCount, lineEntry...
@endcode
Note: the return value must be freed by calling sl_free_buffer after use
Implementation
@ffi.Native<
ffi.Pointer<ffi.Int32> Function(sl_analyzer_handle_t, ffi.Pointer<ffi.Int32>)
>(assetId: _sweetlineAssetId)
external ffi.Pointer<ffi.Int32> sl_document_get_highlight_slice(
sl_analyzer_handle_t analyzer_handle,
ffi.Pointer<ffi.Int32> visible_range,
);