sl_error enum
Error codes
Values
- SL_OK → const sl_error
-
const sl_error(0) - SL_HANDLE_INVALID → const sl_error
-
const sl_error(1) - SL_JSON_PROPERTY_MISSED → const sl_error
-
const sl_error(-1) - SL_JSON_PROPERTY_INVALID → const sl_error
-
const sl_error(-2) - SL_PATTERN_INVALID → const sl_error
-
const sl_error(-3) - SL_STATE_INVALID → const sl_error
-
const sl_error(-4) - SL_JSON_INVALID → const sl_error
-
const sl_error(-5) - SL_FILE_IO_ERR → const sl_error
-
const sl_error(-6) - SL_FILE_EMPTY → const sl_error
-
const sl_error(-7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited